@@ -12,7 +12,7 @@
 #' @source <https://www1.nseindia.com/products/content/all_daily_reports.htm>, <https://www.bseindia.com/markets/marketinfo/BhavCopy.aspx>
 #' @seealso \code{\link[nser]{bhavpr}}\code{\link[nser]{bhavtoday}}
 #'
-#' @import stats
+#' @import stats httr
 #' @importFrom utils download.file read.csv unzip
 #' @importFrom curl has_internet
 #' @export
@@ -25,12 +25,14 @@
 #' report = bhav("01072021", 'BSE')
 #' }
 bhav = function(x, se = 'NSE'){
-  # First check internet connection
-  if (!curl::has_internet()) {
-    message("No internet connection.")
-    return(invisible(NULL))
+  # Check for internet connection
+  if (curl::has_internet()){
+    message("Downloading Bhavcopy")
+  } else {
+    message("No internet connection")
   }
 
+
   if(!nchar(gsub("[^0-9]+", "", x)) == 8){
     print("Check the date. It should be an Eight digit interger.")
   } else{
@@ -73,6 +75,27 @@ bhav = function(x, se = 'NSE'){
     zipname = paste0("cm", dy, mt, yr, "bhav", ".csv")
 
     bhav1 = function(x){
+      try_GET <- function(x, ...) {
+        tryCatch(
+          GET(url = x, timeout(10), ...),
+          error = function(e) conditionMessage(e),
+          warning = function(w) conditionMessage(w)
+        )
+      }
+      is_response <- function(x) {
+        class(x) == "response"
+      }
+
+      resp <- try_GET(bhavurl)
+      if (!is_response(resp)) {
+        message(resp)
+        return(invisible(NULL))
+      }
+      # Then stop if status > 400
+      if (http_error(resp)) {
+        message_for_status(resp)
+        return(invisible(NULL))
+      }
       temp <- tempfile()
       download.file(bhavurl, temp)
       file = read.csv(unz(temp, filename = zipname))
@@ -81,6 +104,27 @@ bhav = function(x, se = 'NSE'){
     }
 
     bhav2 = function(x){
+      try_GET <- function(x, ...) {
+        tryCatch(
+          GET(url = x, timeout(10), ...),
+          error = function(e) conditionMessage(e),
+          warning = function(w) conditionMessage(w)
+        )
+      }
+      is_response <- function(x) {
+        class(x) == "response"
+      }
+
+      resp <- try_GET(bhavurl1)
+      if (!is_response(resp)) {
+        message(resp)
+        return(invisible(NULL))
+      }
+      # Then stop if status > 400
+      if (http_error(resp)) {
+        message_for_status(resp)
+        return(invisible(NULL))
+      }
       temp <- tempfile()
       download.file(bhavurl1, temp)
       file = read.csv(unz(temp, filename = zipname))
@@ -96,6 +140,27 @@ bhav = function(x, se = 'NSE'){
     bsezip = paste0('EQ_ISINCODE_', dy, mt1, yr1, '.CSV')
 
     bsebhav = function(x){
+      try_GET <- function(x, ...) {
+        tryCatch(
+          GET(url = x, timeout(10), ...),
+          error = function(e) conditionMessage(e),
+          warning = function(w) conditionMessage(w)
+        )
+      }
+      is_response <- function(x) {
+        class(x) == "response"
+      }
+
+      resp <- try_GET(bseurl)
+      if (!is_response(resp)) {
+        message(resp)
+        return(invisible(NULL))
+      }
+      # Then stop if status > 400
+      if (http_error(resp)) {
+        message_for_status(resp)
+        return(invisible(NULL))
+      }
       temp <- tempfile()
       download.file(bseurl, temp)
       file = read.csv(unz(temp, filename = bsezip))
