@@ -15,11 +15,10 @@
 #' @source <https://www1.nseindia.com/products/content/derivatives/equities/archieve_fo.htm>
 #' @seealso \code{\link[nser]{bhavpr}}\code{\link[nser]{bhavtoday}}\code{\link[nser]{bhav}}\code{\link[nser]{fobhav}}\code{\link[nser]{bhavs}}
 #'
-#' @import stats
+#' @import stats httr
 #' @import RSelenium
 #' @importFrom utils download.file read.csv unzip
 #' @importFrom curl has_internet
-#'
 #' @export
 #'
 #' @examples \dontrun{ # Start a selenium server and browser
@@ -39,6 +38,7 @@
 #'}
 #'
 bhavfos = function(x, n = 0){
+
   Sys.sleep(n)
   x = as.character(x)
   dy = substr(x, start = 0, stop = 2)
@@ -49,6 +49,37 @@ bhavfos = function(x, n = 0){
   bhavurl = paste0(baseurl, dy, "-", mt, "-", yr, end)
   zipname = paste0("cm", dy, mt, yr, "bhav", ".csv", ".zip")
 
+  # Check for internet connection
+  if (curl::has_internet()){
+    message("Downloading Bhavcopy")
+  } else {
+    message("No internet connection")
+  }
+
+  try_GET <- function(x, ...) {
+    tryCatch(
+      GET(url = x, timeout(10), ...),
+      error = function(e) conditionMessage(e),
+      warning = function(w) conditionMessage(w)
+    )
+  }
+  is_response <- function(x) {
+    class(x) == "response"
+  }
+
+
+  resp <- try_GET(bhavurl)
+  if (!is_response(resp)) {
+    message(resp)
+    return(invisible(NULL))
+  }
+  # Then stop if status > 400
+  if (http_error(resp)) {
+    message_for_status(resp)
+    return(invisible(NULL))
+  }
+
+
   remDr$navigate(bhavurl)
   address_element1 <- remDr$findElement(using ="xpath", '/html/body/table/tbody/tr/td/a[1]')
   Sys.sleep(n)
