@@ -12,7 +12,7 @@
 #'
 #' @seealso \code{\link[nser]{bhavpr}}\code{\link[nser]{bhavtoday}}
 #'
-#' @import stats
+#' @import stats httr
 #' @importFrom utils download.file read.csv unzip
 #' @importFrom curl has_internet
 #'
@@ -21,10 +21,12 @@
 #' @examples report = fobhav("01072021") # Download F&O bhavcopy for 01 July 2021
 #' report
 fobhav = function(x){
-  # check internet connection
-  if (!curl::has_internet()) {
-    message("No internet connection.")
-    return(invisible(NULL))
+
+  # Check for internet connection
+  if (curl::has_internet()){
+    message("Downloading Bhavcopy")
+  } else {
+    message("No internet connection")
   }
 
 if(!nchar(gsub("[^0-9]+", "", x)) == 8){
@@ -66,6 +68,28 @@ if(!nchar(gsub("[^0-9]+", "", x)) == 8){
        bhavurl = paste0(baseurl, yr, "/", mt, "/fo", dy, mt, yr, "bhav", end)
        zipname = paste0("fo", dy, mt, yr, "bhav", ".csv")
 
+       try_GET <- function(x, ...) {
+         tryCatch(
+           GET(url = x, timeout(10), ...),
+           error = function(e) conditionMessage(e),
+           warning = function(w) conditionMessage(w)
+         )
+       }
+       is_response <- function(x) {
+         class(x) == "response"
+       }
+
+       resp <- try_GET(bhavurl)
+       if (!is_response(resp)) {
+         message(resp)
+         return(invisible(NULL))
+       }
+       # Then stop if status > 400
+       if (httr::http_error(resp)) {
+         message_for_status(resp)
+         return(invisible(NULL))
+       }
+
        temp <- tempfile()
        download.file(bhavurl, temp)
        file <-  read.csv(unz(temp, filename = zipname))
