@@ -20,13 +20,17 @@
 #' nseindex()
 #' }
 nseindex = function(){
-  # First check internet connection
-  if (!curl::has_internet()) {
-    message("No internet connection.")
-    return(invisible(NULL))
+  # Check for internet connection
+  if (curl::has_internet()){
+    message("Working")
+  } else {
+    message("No internet connection")
   }
 
-  dat = fromJSON('https://www1.nseindia.com/homepage/Indices1.json')
+  bhavurl = "https://www1.nseindia.com/homepage/Indices1.json"
+
+  dat = fromJSON(bhavurl)
+
   live = dat[["data"]]
   live = live[,-5]
   live = `colnames<-`(live, c("NAME", "Last Price", "Change", "pChange"))
