@@ -14,6 +14,8 @@
 #'
 #' @import stats
 #' @importFrom jsonlite fromJSON
+#' @importFrom curl has_internet
+#'
 #' @export
 #' @examples \dontrun{
 #' # NSE Pre market open data of Nifty 50 stocks
@@ -24,6 +26,13 @@
 #' nseopen("fo")
 #' }
 nseopen = function(x = "n50"){
+  # Check for internet connection
+  if (curl::has_internet()){
+    message("Working")
+  } else {
+    message("No internet connection")
+  }
+
   if(x == "n50"){
 dat = fromJSON('https://www1.nseindia.com/live_market/dynaContent/live_analysis/pre_open/nifty.json')
 open = dat[["data"]]
@@ -42,6 +51,13 @@ message("\nAdvances - ", adv, "\n",
 return(num)
   }
   else if(x == "fo"){
+    # Check for internet connection
+    if (curl::has_internet()){
+      message("Working")
+    } else {
+      message("No internet connection")
+    }
+
     dat = fromJSON('https://www1.nseindia.com/live_market/dynaContent/live_analysis/pre_open/fo.json')
     open = dat[["data"]]
     open = open[,-c(2,3,4,14,15,16,17)]
@@ -59,6 +75,13 @@ return(num)
     return(num)
   }
   else if(x == "all"){
+    # Check for internet connection
+    if (curl::has_internet()){
+      message("Working")
+    } else {
+      message("No internet connection")
+    }
+
     dat = fromJSON('https://www1.nseindia.com/live_market/dynaContent/live_analysis/pre_open/all.json')
     open = dat[["data"]]
     open = open[,-c(2,3,4,14,15,16,17)]
